/*****************************************************************************\
  phobos_cmaps.cpp : Color maps for DJ8x5

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

#include "global_types.h"

#ifdef APDK_DJ8x5

APDK_BEGIN_NAMESPACE

uint32_t ulMapPhobosDraft[ 9 * 9 * 9 ] =
{
4294967040UL, 3034836992UL, 2094464768UL, 1439104512UL,  867696128UL,  582024704UL,
 312933888UL,   94633472UL,   10551040UL, 4289449216UL, 3469671936UL, 2093612544UL,
1287847424UL,  716373504UL,  346684928UL,  195559168UL,   27459072UL,   10484992UL,
4268873216UL, 3834046464UL, 2290873088UL, 1267724032UL,  613875200UL,  160890368UL,
  26803712UL,   26803712UL,    9960960UL, 4266904576UL, 4267370752UL, 3026120448UL,
1616965888UL,  795474688UL,  225704960UL,   24836352UL,   25360896UL,    8780288UL,
4264934400UL, 4265267712UL, 3443514880UL, 2135023616UL, 1094903296UL,  474869248UL,
  22737664UL,   23522560UL,    7270144UL, 4263686656UL, 4246913280UL, 3676818176UL,
2502677504UL, 1630330112UL,  724361472UL,  188345344UL,   21619712UL,    5760000UL,
4262636288UL, 4262704384UL, 3793140736UL, 2769993216UL, 1998310656UL, 1226434816UL,
 387512832UL,   19394816UL,    4120576UL, 4261783552UL, 4261850368UL, 3859525376UL,
3020796928UL, 2215557632UL, 1695341824UL,  873133312UL,  151715584UL,    2156288UL,
4278230528UL, 4244676864UL, 3741358592UL, 3103824128UL, 2298518784UL, 1711320320UL,
1325455360UL,  604040960UL,      65280UL, 4160200192UL, 2818485760UL, 1744750848UL,
 956104192UL,  366869760UL,  147455488UL,   29163008UL,   28376320UL,   11009280UL,
4273584384UL, 3284386560UL, 2042811904UL, 1135996416UL,  430439168UL,   27459328UL,
  26604544UL,   26143744UL,    9234176UL, 4269058816UL, 3917791232UL, 2357640448UL,
1334362112UL,  663143936UL,   42392832UL,   25615872UL,   25615872UL,    8773888UL,
4283413504UL, 3797201152UL, 2640033024UL, 1700772864UL,  879085568UL,  308924928UL,
  23976704UL,   24369920UL,    7921664UL, 4264931840UL, 3828789760UL, 2956831744UL,
1916711424UL, 1161803776UL,  524730368UL,   55428608UL,    5817856UL,    6542336UL,
4280265472UL, 4062030592UL, 3173165312UL, 2200479488UL, 1445506048UL,  791261696UL,
 271628288UL,   20757248UL,    4964864UL, 4262241024UL, 3976961280UL, 3289357568UL,
2383715072UL, 1729536000UL, 1041671424UL,  471248384UL,   35501568UL,    3456512UL,
4261518848UL, 3674246400UL, 3288436224UL, 2550435840UL, 1963495936UL, 1359452928UL,
 721920256UL,  201764864UL,    1620992UL, 4127232000UL, 3355476224UL, 3170927872UL,
2734721280UL, 2181073920UL, 1694537216UL, 1140891904UL,  553691648UL,   16890880UL,
4278022656UL, 3422451200UL, 2029942784UL,  922653184UL,  182366720UL,   13814528UL,
  29679616UL,   28697600UL,   11332096UL, 4274286848UL, 3688530688UL, 2128250368UL,
1103925760UL,  398306048UL,   29015040UL,   27706624UL,   26855680UL,    9490176UL,
4271544832UL, 3751516160UL, 2560137216UL, 1452123136UL,  696365056UL,   25018368UL,
   8243200UL,   25085184UL,    8242176UL, 4266887168UL, 4183726592UL, 2892207616UL,
1818532096UL,  929471232UL,  292070656UL,    7122688UL,    7516928UL,    7583232UL,
4265123840UL, 3812268544UL, 3040711168UL, 2017629184UL, 1245944320UL,  558341376UL,
  38510848UL,   22653184UL,    6402048UL, 4263485440UL, 3844054016UL, 3089273856UL,
2250740224UL, 1512740096UL,  858429440UL,  271620864UL,   20751104UL,    4826368UL,
4262303488UL, 3708522240UL, 3037431808UL, 2282718976UL, 1679067392UL, 1058376960UL,
 504729600UL,   35494656UL,    3318272UL, 4278292224UL, 3422650112UL, 2885712896UL,
2332130816UL, 1778614016UL, 1241744128UL,  705005824UL,  184913920UL,    1546752UL,
3590356480UL, 3070260480UL, 2600497152UL, 2315285760UL, 1929410304UL, 1526758144UL,
1040220160UL,  520128256UL,      36864UL, 4277355264UL, 3690873856UL, 2197770752UL,
1308511488UL,  367881984UL,   32278784UL,   30059264UL,   29736192UL,   12176640UL,
4275392768UL, 3890565888UL, 2312591872UL, 1406624000UL,  517107200UL,   29656064UL,
  28548608UL,   11315712UL,   10596864UL, 4270676224UL, 4037107968UL, 2694734592UL,
1554016000UL,  714699776UL,   60392704UL,    9933824UL,    9477632UL,    8955392UL,
4284966656UL, 3714606848UL, 2707908352UL, 1768515840UL, 1013546240UL,  358910976UL,
  23501568UL,    6988544UL,    6988288UL, 4265305856UL, 4215238144UL, 2890034688UL,
1866689024UL, 1229286912UL,  558330880UL,   38502912UL,    5803520UL,    6198528UL,
4213408512UL, 3710023936UL, 2804116480UL, 1982229504UL, 1361800448UL,  824931072UL,
 271613184UL,    3966208UL,    4688128UL, 4128081664UL, 3524099072UL, 2852876288UL,
2131717376UL, 1511222016UL,  957705472UL,  471168256UL,   18710272UL,    3245056UL,
3942677760UL, 3221319424UL, 2701224448UL, 2181065216UL, 1677814016UL, 1141073920UL,
 637759232UL,  184841472UL,    1408768UL, 3338694912UL, 2902484992UL, 2449498624UL,
2164286208UL, 1795188224UL, 1375757568UL,  973170944UL,  486567168UL,      29440UL,
4227734784UL, 3606979072UL, 2566793472UL, 1509897984UL,  788410112UL,   15227392UL,
  14709504UL,   30706688UL,   12559872UL, 4275383040UL, 3773114368UL, 2565222400UL,
1557806336UL,  819218176UL,   64116224UL,   29649664UL,   28412160UL,   11245568UL,
4272698880UL, 3719249408UL, 2897297920UL, 1806976768UL,  968444928UL,  179066112UL,
  27290624UL,   26902784UL,    9866496UL, 4285088256UL, 4151527424UL, 2994096896UL,
2021150464UL, 1098535168UL,  343694080UL,    7890688UL,    7697152UL,    7699968UL,
4249899008UL, 3729871872UL, 3109115136UL, 2152748288UL, 1381126656UL,  642735872UL,
  71787776UL,    5074944UL,    5537024UL, 4264186880UL, 4046018304UL, 3173799680UL,
2133677824UL, 1429165312UL,  858740736UL,  288578816UL,   20604160UL,    4352512UL,
4279329536UL, 3708837376UL, 2937084160UL, 2165331712UL, 1544770816UL,  974542592UL,
 488070144UL,    1860608UL,    2976000UL, 3791677696UL, 3271581440UL, 2801818368UL,
2181060608UL, 1661032192UL, 1124161024UL,  604198656UL,  167993088UL,    1337088UL,
3271582208UL, 2969590528UL, 2466272512UL, 2130793728UL, 1761629952UL, 1342199040UL,
 922768384UL,  486562560UL,      24320UL, 4277930240UL, 3841853952UL, 2935886080UL,
1778325760UL, 1023287808UL,  436148480UL,   33244416UL,   14377984UL,   13990912UL,
4293788928UL, 3840804352UL, 2917666304UL, 1709447680UL,  937501184UL,  366488320UL,
  30230784UL,   29777152UL,   12087296UL, 4288943872UL, 4038202880UL, 2813204992UL,
1806246400UL, 1051207936UL,  447558144UL,   28328704UL,   27679232UL,   10448896UL,
4285997312UL, 3799524864UL, 2775984640UL, 1920413184UL, 1199124480UL,  545273088UL,
  25510912UL,   25517312UL,    8546560UL, 4283642624UL, 3696440064UL, 2824222464UL,
2086222080UL, 1465465088UL,  710753280UL,   56574976UL,    6640640UL,    6512128UL,
4248385792UL, 3711516160UL, 3157802752UL, 2369273600UL, 1631142144UL, 1010580480UL,
 339298816UL,   20599296UL,    4152320UL, 4246290944UL, 4028056320UL, 3189129472UL,
2283225600UL, 1612267520UL, 1025130240UL,  504971776UL,   18827520UL,    3035904UL,
4261563904UL, 3640740096UL, 2969650688UL, 2248229888UL, 1677804288UL, 1141063936UL,
 604258560UL,  168053248UL,    1331712UL, 3439415552UL, 2986429184UL, 2516600576UL,
2114012416UL, 1728071168UL, 1325417472UL,  905986560UL,  469780224UL,      19968UL,
4294508544UL, 4076732672UL, 3372089856UL, 2298414336UL, 1325337600UL,  603851776UL,
 117311232UL,   32782848UL,   14441216UL, 4209574144UL, 3789816064UL, 3169124608UL,
2246836480UL, 1189545984UL,  535367168UL,   65017856UL,   29900032UL,   13193984UL,
4272948480UL, 3938517248UL, 3065839872UL, 2126578176UL, 1203244288UL,  565318400UL,
  28319232UL,   11352064UL,   11423488UL, 4270327808UL, 3750102784UL, 2927823360UL,
2021723904UL, 1317147392UL,  646256640UL,  125967872UL,   25572864UL,    9195264UL,
4267186176UL, 3797489152UL, 2891520000UL, 2035948288UL, 1448680960UL,  828186368UL,
 224404224UL,   23738624UL,    7556352UL, 4231865088UL, 3392741888UL, 2721719040UL,
2084316416UL, 1513956096UL, 1010771200UL,  356722944UL,    4666624UL,    5325824UL,
4263584000UL, 3726714880UL, 3173067008UL, 2367695104UL, 1780689664UL, 1143024384UL,
 640034304UL,    2175744UL,    2965760UL, 4262015488UL, 3959762944UL, 3271896832UL,
2365926912UL, 1694772224UL, 1158032128UL,  621160960UL,  185020160UL,    1456128UL,
3607116288UL, 2986358016UL, 2499818496UL, 2097231104UL, 1694577920UL, 1308635904UL,
 838872576UL,  452997120UL,      14080UL, 4260691968UL, 4194107648UL, 3607035904UL,
2784887040UL, 1811873792UL, 1040057088UL,  452920064UL,   16711936UL,   16068352UL,
4007657728UL, 3654811904UL, 3235578112UL, 2514157568UL, 1692598272UL,  887291904UL,
 300155136UL,   31198720UL,   13447680UL, 4207018240UL, 3821076736UL, 3166765312UL,
2378039296UL, 1707343872UL,  834797824UL,  230818048UL,   28644352UL,   11415296UL,
4186636288UL, 3632857088UL, 3146842112UL, 2241003776UL, 1586495744UL,  797835520UL,
 194249216UL,   26022400UL,    8923904UL, 3865968896UL, 3530162176UL, 2892300288UL,
2170683392UL, 1549861888UL,  912459264UL,  359139328UL,    6755072UL,    7023872UL,
4265937920UL, 3561097984UL, 2856388864UL, 2118257408UL, 1547832320UL, 1061293568UL,
 474353152UL,   21698048UL,    5648128UL, 4264105216UL, 3324450048UL, 2703561216UL,
2099647232UL, 1613239296UL, 1126699776UL,  640291328UL,   19731968UL,    3614976UL,
4262399744UL, 3624736000UL, 3054244864UL, 2315982080UL, 1745688320UL, 1208817152UL,
 738989824UL,  269488128UL,    1516800UL, 3842056448UL, 3154124800UL, 2583699200UL,
2130713856UL, 1660952320UL, 1275141888UL,  822090752UL,  452992512UL,       8448UL,
4294377472UL, 4277993472UL, 3841851392UL, 3187539968UL, 2331770880UL, 1492975616UL,
 922550272UL,  452853760UL,   16711680UL, 3889758208UL, 3654680576UL, 3319332864UL,
2866479104UL, 2195980288UL, 1390804992UL,  820379648UL,  367394816UL,   15007744UL,
4005691392UL, 3770548224UL, 3267428352UL, 2596274176UL, 2110062592UL, 1304821760UL,
 734265344UL,  247988224UL,   12713984UL, 3868000256UL, 3532455936UL, 3248095232UL,
2375680000UL, 1838678016UL, 1251409920UL,  664141824UL,  195035136UL,   10027008UL,
3446734848UL, 3228499968UL, 2809004032UL, 2339373056UL, 1768751104UL, 1298989056UL,
 661651456UL,  158597120UL,    7405568UL, 3679256576UL, 3360424192UL, 2840396032UL,
2219638784UL, 1632174080UL, 1162346496UL,  659226624UL,  156237824UL,    5373952UL,
4214226944UL, 3475832832UL, 2821521408UL, 2150432768UL, 1630339072UL, 1160577024UL,
 707461120UL,  187891712UL,    3932160UL, 4094624000UL, 3624861952UL, 2735603712UL,
2081489152UL, 1578106880UL, 1125122048UL,  705757184UL,  286523392UL,    1966080UL,
4278190080UL, 2919301376UL, 2499870976UL, 2113929216UL, 1728119040UL, 1224736768UL,
 922746880UL,  520093696UL,          0
};

uint32_t ulMapPhobosPlainNormal[9 * 9 * 9] =
{
4294967040UL, 2681863936UL, 1723662080UL, 1286209280UL, 1033699072UL,  831782656UL,
 630062848UL,  377552640UL,    7077632UL, 4289394944UL, 3250716416UL, 1940848384UL,
1352793856UL,  999554816UL,  730595072UL,  528744192UL,  360447744UL,    6484992UL,
4284473856UL, 3564568320UL, 2475949824UL, 1619721984UL, 1082326784UL,  695795456UL,
 409992960UL,  225050368UL,    5961984UL, 4281847296UL, 3946771968UL, 2824666880UL,
2038038272UL, 1399848704UL,  811859712UL,  257031936UL,   72154880UL,    4913152UL,
4280337408UL, 4196592384UL, 3375365888UL, 2236350208UL, 1718025984UL, 1197342464UL,
 457441024UL,    3470336UL,    3729152UL, 4279484416UL, 4279556864UL, 3843227392UL,
2619473664UL, 1765539584UL, 1482227456UL,  893910784UL,  170521600UL,    2677248UL,
4278893056UL, 4278897664UL, 4093701376UL, 3087466240UL, 1930755840UL, 1429208832UL,
1280114432UL,  422181120UL,    1824768UL, 4278235136UL, 4278238464UL, 4160804352UL,
3355501056UL, 2281761792UL, 1376253696UL, 1042218752UL,  943259392UL,     974848UL,
4278233088UL, 4278235648UL, 3976248320UL, 3338716672UL, 2583744256UL, 1711331584UL,
 973136384UL,  436266240UL,      65280UL, 4110406144UL, 2634009088UL, 1391848192UL,
 937426688UL,  734461696UL,  615644928UL,  513736448UL,  378339072UL,    7206912UL,
4290824704UL, 3621509376UL, 1875640064UL, 1236532992UL,  882835200UL,  630324992UL,
 428080896UL,  225902336UL,    6813696UL, 4284791040UL, 3766348032UL, 2493117696UL,
1553071872UL,  965017344UL,  544866048UL,  258801408UL,    6553344UL,    6026240UL,
4281905408UL, 4148093696UL, 2891379456UL, 1936717056UL, 1298988800UL,  610008832UL,
  71958272UL,    4846592UL,    4975360UL, 4280397312UL, 4280538112UL, 3391483904UL,
2084236800UL, 1448014080UL,  927791360UL,  154202624UL,    3333120UL,    3791360UL,
4279414016UL, 4279224320UL, 3674924800UL, 2366825472UL, 1360979968UL,  706929664UL,
 236840192UL,    1954304UL,    2542080UL, 4278692352UL, 4194350592UL, 3691039232UL,
2617298432UL, 1543558400UL,  789108992UL,  269079296UL,     773120UL,    1622784UL,
4278232064UL, 3774913280UL, 3355485696UL, 2684399360UL, 1828762880UL, 1090568448UL,
 520144640UL,  100713728UL,     835584UL, 4076901376UL, 3523250944UL, 3221262848UL,
2751503360UL, 2097193472UL, 1426107392UL,  872463104UL,  402702848UL,      50432UL,
4060054784UL, 2734657280UL, 1493143808UL,  822070528UL,  452062976UL,  383319808UL,
 330891008UL,  211615488UL,    8255744UL, 4291788544UL, 3353781760UL, 1609677312UL,
 670359808UL,  333379584UL,  247398144UL,  144834304UL,    8714496UL,    7467008UL,
4286677248UL, 3969559040UL, 2442827008UL, 1168235008UL,  613479680UL,  259848960UL,
  74381568UL,    6615040UL,    6217728UL, 4282417664UL, 4182551040UL, 2823467776UL,
1465630720UL,  727374848UL,  156167936UL,    4974592UL,    5168640UL,    5101056UL,
4280650752UL, 4280854272UL, 3340811520UL, 1865007104UL,  825017344UL,  254333696UL,
   2872064UL,    3591424UL,    3983872UL, 4279537920UL, 4279346688UL, 3540826624UL,
2198780672UL, 1125302016UL,  403685632UL,   51562496UL,    1949184UL,    2604032UL,
4278686464UL, 4160788992UL, 3405816576UL, 2365630976UL, 1392553984UL,  704690176UL,
 218412800UL,     701184UL,    1552128UL, 4278226176UL, 3640689408UL, 3103820032UL,
2466288640UL, 1660983552UL, 1040228608UL,  503359488UL,  117483520UL,     697088UL,
3825237248UL, 3338696192UL, 2936043520UL, 2449506560UL, 1845528064UL, 1291881216UL,
 805344512UL,  385916416UL,      39936UL, 4110371584UL, 2986300160UL, 1577016576UL,
 889153024UL,  402628352UL,   16765440UL,   14477824UL,   12252160UL,    9956352UL,
4292430592UL, 3572784640UL, 1777297920UL,  737835520UL,  116958976UL,   14732288UL,
  12901632UL,   10673664UL,    8772096UL, 4287844864UL, 4055196672UL, 2259116544UL,
 867532032UL,  179740928UL,   11058688UL,    9882368UL,    8637952UL,    7391744UL,
4283519232UL, 4284771328UL, 2975821824UL, 1465539328UL,  509779456UL,   72859136UL,
   5621760UL,    5621248UL,    5488384UL, 4280966400UL, 4281233152UL, 3392045056UL,
1848411136UL,  707562496UL,  238003200UL,    3453440UL,    3978752UL,    4240896UL,
4279659520UL, 4279663104UL, 3507782912UL, 2182318336UL, 1108709120UL,  437557248UL,
   1550080UL,    2204672UL,    2926336UL, 4278744064UL, 4160780032UL, 3405806336UL,
2332066816UL, 1359186688UL,  671387904UL,  201692928UL,     825344UL,    1611776UL,
4211110656UL, 3607128320UL, 3070258176UL, 2365617664UL, 1593867264UL,  989888768UL,
 469796608UL,  100698112UL,     625152UL, 3674236416UL, 3238027520UL, 2868929280UL,
2365614592UL, 1778413312UL, 1207987968UL,  771782144UL,  369130752UL,      31488UL,
4227803648UL, 3355389952UL, 1828665344UL,  922697472UL,  469713664UL,   83849984UL,
  15508736UL,   13614848UL,   11650304UL, 4292815104UL, 3774821376UL, 2079931136UL,
 788021248UL,  201018368UL,   15234304UL,   13803520UL,   12498432UL,   10467328UL,
4288491264UL, 4123211520UL, 2579379200UL,  934885632UL,  231099904UL,   12350208UL,
  11572736UL,   10265856UL,    8759808UL, 4284233216UL, 4285808640UL, 2977381632UL,
1433485312UL,  561796864UL,   58289920UL,    7834112UL,    7444992UL,    6659584UL,
4281678080UL, 4282073856UL, 3325379072UL, 1882737664UL, 1145391104UL,  306016256UL,
   3966208UL,    4429312UL,    4494592UL, 4280107776UL, 4280109568UL, 3491254016UL,
2233095168UL, 1193237760UL,  505309184UL,   69105152UL,    2654208UL,    3180800UL,
4278931200UL, 4278735616UL, 3439809792UL, 2366134272UL, 1359568384UL,  722101760UL,
 235498496UL,    1078272UL,    1800960UL, 4177548288UL, 3657453056UL, 3053473536UL,
2382386432UL, 1560304384UL,  922771200UL,  453010688UL,   67134976UL,     748544UL,
3573567488UL, 3187690240UL, 2818592000UL, 2332054016UL, 1744853248UL, 1174428416UL,
 738221056UL,  369123840UL,      24832UL, 4294907648UL, 3607042560UL, 2264866304UL,
1023353856UL,  486483456UL,  201271296UL,   16077824UL,   14450432UL,   12818944UL,
4293138688UL, 3909032448UL, 2482969600UL,  922362112UL,  217719040UL,   15740928UL,
  14571520UL,   13204480UL,   11636992UL, 4289273088UL, 4190903296UL, 2815367424UL,
1204165376UL,  298196992UL,   12923904UL,   12409088UL,   11236864UL,    9864448UL,
4285080064UL, 4202570752UL, 2995003392UL, 1635853312UL,  612641024UL,   92944128UL,
   9065472UL,    8613120UL,    7699200UL, 4282197504UL, 4165150720UL, 3057722112UL,
1883712256UL,  978138112UL,  323894272UL,    5131264UL,    5465088UL,    5337088UL,
4280559872UL, 4280626176UL, 3340445184UL, 2233544448UL, 1244150016UL,  791556096UL,
  69683712UL,    2972928UL,    3368960UL, 4279316224UL, 4279251456UL, 3456840192UL,
2399942144UL, 1410284288UL,  739197440UL,  235751424UL,    1331968UL,    2055680UL,
4177540096UL, 3808441600UL, 3103798784UL, 2365602304UL, 1526742272UL,  889209088UL,
 419448064UL,      18688UL,     873728UL, 3456121600UL, 3087022336UL, 2701146624UL,
2214607872UL, 1644183296UL, 1124090624UL,  687883264UL,  369117184UL,      18688UL,
4294380544UL, 3825142784UL, 2768178688UL, 1325338880UL,  570364928UL,  218043648UL,
  16389120UL,   15547904UL,   13919232UL, 4293135360UL, 3992913920UL, 2835286016UL,
1241450752UL,  267848704UL,   15733504UL,   14885632UL,   13976320UL,   12869888UL,
4289793536UL, 4174252288UL, 2949842432UL, 1506740224UL,  398920448UL,   12981248UL,
  12658688UL,   12338432UL,   11099392UL, 4285796608UL, 4186247424UL, 2995457536UL,
1753878528UL,  747377408UL,  143529984UL,    9578752UL,    9651200UL,    8804352UL,
4282717696UL, 4131984896UL, 3058307840UL, 1934628608UL, 1062607616UL,  374742528UL,
   5974016UL,    6438912UL,    6181120UL, 4280884224UL, 3928299264UL, 2988709120UL,
2083199744UL, 1261444864UL,  556868096UL,  103885056UL,    3685120UL,    4016384UL,
4279638784UL, 4195621632UL, 3389986816UL, 2400394496UL, 1461002752UL,  789915904UL,
 488381952UL,    1651968UL,    2245376UL, 4278525440UL, 4076871168UL, 3288341760UL,
2365595648UL, 1476403712UL,  855647744UL,  385886976UL,      12544UL,     932352UL,
3506447616UL, 2986353664UL, 2600477952UL, 2080384768UL, 1577069056UL, 1090530560UL,
 637546240UL,  352334336UL,      13312UL, 4293591040UL, 4026204160UL, 3154051072UL,
1862206720UL,  788465664UL,  318703616UL,  100599808UL,   16321792UL,   15150848UL,
4292804608UL, 4025286656UL, 3052339200UL, 1794113536UL,  569376768UL,   15532032UL,
  14814208UL,   14358272UL,   13775104UL, 4289921024UL, 3904962560UL, 2982477824UL,
1858535424UL,  700907520UL,   12910592UL,   12652032UL,   12590080UL,   12137216UL,
4286382080UL, 3984850944UL, 2928279552UL, 1837957120UL,  898629632UL,  227673088UL,
   9834240UL,   10034688UL,    9778432UL, 4283107328UL, 4014802432UL, 3025208832UL,
1918174720UL, 1113131008UL,  458885632UL,    6098176UL,    6889472UL,    7156992UL,
4281142528UL, 3794471424UL, 2955610368UL, 2050034432UL, 1261767936UL,  641142784UL,
 137826816UL,    4202496UL,    4600320UL, 4279898368UL, 3692235264UL, 2970946304UL,
2149125632UL, 1377505536UL,  807211520UL,  253498112UL,    2039040UL,    2567168UL,
4278783488UL, 4043771136UL, 3322219776UL, 2466648064UL, 1611076096UL,  939988480UL,
 436607232UL,  168430592UL,    1123584UL, 3841987072UL, 3087012608UL, 2600473600UL,
2113934848UL, 1560287488UL, 1073748736UL,  637541632UL,  335552256UL,       8192UL,
4292411392UL, 4142923776UL, 3455778816UL, 2399076352UL, 1224671232UL,  553582592UL,
 251592704UL,   16711680UL,   16711680UL, 3972530176UL, 3653959680UL, 3168141312UL,
2279211008UL, 1189150720UL,  450953216UL,  149094400UL,   14745600UL,   14417920UL,
3802660864UL, 3433889792UL, 2947809280UL, 2193096704UL, 1254031360UL,  465436672UL,
  96468992UL,   12517376UL,   12517376UL, 3783065600UL, 3431137280UL, 2861301760UL,
2106589184UL, 1301544960UL,  546635776UL,   93716480UL,   10158080UL,   10289152UL,
3914334208UL, 3411083264UL, 2824339456UL, 2019426304UL, 1298202624UL,  644022272UL,
 140705792UL,    6881280UL,    7602176UL, 4197449728UL, 3593469952UL, 2788294656UL,
2016804864UL, 1278869504UL,  708509696UL,  222035968UL,    4325376UL,    5177344UL,
4011327488UL, 3591897088UL, 2870542336UL, 2098987008UL, 1360855040UL,  756940800UL,
 287244288UL,    2424832UL,    3080192UL, 3976658944UL, 3607560192UL, 3003580416UL,
2215116800UL, 1476919296UL,  856227840UL,  420085760UL,     851968UL,    1376256UL,
4278190080UL, 3472883712UL, 2734686208UL, 2164260864UL, 1677721600UL, 1157627904UL,
 721420288UL,  301989888UL,          0
};

/*
uint32_t ulMapPhobosPhoto[9 * 9 * 9] =
{
3503543808UL, 3100498688UL, 2495668736UL, 1890903552UL, 1370285568UL,  916973056UL,
 514057728UL,  161604864UL,   10610176UL, 3718890240UL, 2964445952UL, 2545080832UL,
1756291072UL, 1051191040UL,  497280512UL,  144827904UL,   10412288UL,   10346496UL,
3800809728UL, 3364931072UL, 2543178496UL, 1973014272UL, 1117311488UL,  244766464UL,
   9884160UL,    9883904UL,    9883904UL, 3831938816UL, 3463298560UL, 2910240256UL,
2189214720UL, 1451148544UL,  595510528UL,    8306688UL,    8634112UL,    8896512UL,
3678649344UL, 3444226816UL, 3025385728UL, 2539306240UL, 1616757760UL,  929023232UL,
 157597952UL,    7190528UL,    7517440UL, 3576215296UL, 3408836096UL, 3090527744UL,
2721822464UL, 2118106624UL, 1144899584UL,  474203648UL,    5552896UL,    6271232UL,
3473781248UL, 3356799488UL, 3122508032UL, 2820846336UL, 2401809920UL, 1697103360UL,
 706857216UL,  137477888UL,    4632064UL, 3321932032UL, 3238046208UL, 3137711616UL,
2886511872UL, 2584850176UL, 2048176896UL, 1292549120UL,  302498816UL,    2863360UL,
3170934016UL, 3154157568UL, 3053495040UL, 2852168192UL, 2499845120UL, 2046859776UL,
1526766848UL,  956345088UL,      46848UL, 3670715392UL, 3001202176UL, 2279259904UL,
1389152512UL,  599839744UL,  129424384UL,   11394304UL,   11133952UL,   10739968UL,
3819876352UL, 3132799488UL, 2645867520UL, 1941030912UL, 1084936704UL,  212130304UL,
  10540544UL,   10473984UL,   10342144UL, 3868111360UL, 3381965056UL, 2778183168UL,
2140846080UL, 1335540736UL,  513327616UL,    9880064UL,    9880064UL,    9748480UL,
3731337472UL, 3329207552UL, 2876681472UL, 2340270848UL, 1585361920UL,  779990528UL,
  92190976UL,    8566784UL,    8763392UL, 3611537664UL, 3276516352UL, 2924587776UL,
2505681920UL, 1784459264UL, 1063235840UL,  241283584UL,    6925824UL,    7319296UL,
3508973312UL, 3224086784UL, 2955979008UL, 2620893440UL, 2050862080UL, 1296019200UL,
 591638272UL,    5155584UL,    6006528UL, 3439963136UL, 3171656704UL, 2953880576UL,
2669126912UL, 2233443584UL, 1596172288UL,  841394944UL,  154052608UL,    4301568UL,
3254821376UL, 3053492992UL, 2936052992UL, 2701171968UL, 2399444992UL, 1879548160UL,
1208460032UL,  436971008UL,    2531328UL, 3154156288UL, 3053491968UL, 2936051712UL,
2768280064UL, 2516621824UL, 2147523584UL, 1610652672UL,  956341760UL,      41472UL,
3721303296UL, 3201997312UL, 2430573312UL, 1473488384UL,  583643136UL,   12367872UL,
  11977216UL,   11652096UL,   11129600UL, 3837041408UL, 3333921792UL, 2646383872UL,
1958257920UL, 1102293760UL,  162509312UL,   11122176UL,   10992384UL,   10599936UL,
4002650624UL, 3398867200UL, 2728108544UL, 2207950080UL, 1385802496UL,  530035200UL,
   9877248UL,    9746176UL,    9614592UL, 3765148928UL, 3312753920UL, 2893586176UL,
2357044224UL, 1635821056UL,  813672704UL,   75476480UL,    8564224UL,    8630272UL,
3595084288UL, 3226311680UL, 2907872256UL, 2472123904UL, 1818075648UL, 1080009472UL,
 224503040UL,    7055104UL,    7317248UL, 3475612416UL, 3190660352UL, 2905512960UL,
2553584640UL, 2000395776UL, 1279107072UL,  591437568UL,    5086976UL,    5872896UL,
3389825280UL, 3121256960UL, 2886244352UL, 2601490688UL, 2132252928UL, 1511889408UL,
 807443456UL,  120232704UL,    4167936UL, 3238041856UL, 3019936256UL, 2852164096UL,
2634060544UL, 2281739008UL, 1778422528UL, 1157928448UL,  403216384UL,    2397440UL,
3137377280UL, 3003158528UL, 2852163328UL, 2684391424UL, 2415955968UL, 2080411904UL,
1577095168UL,  939561216UL,      37120UL, 3754981376UL, 3285613056UL, 2614722048UL,
1809547008UL,  835620864UL,  113483264UL,   12430080UL,   12038656UL,   11647744UL,
3770055936UL, 3317138176UL, 2780333568UL, 2176485632UL, 1253478656UL,  213162496UL,
  11576320UL,   11053056UL,   10923776UL, 3784868096UL, 3298526464UL, 2862450688UL,
2258733824UL, 1403031296UL,  497063680UL,   10263808UL,   10200064UL,    9807360UL,
3816062976UL, 3329918464UL, 2944305152UL, 2323746048UL, 1686212864UL,  847288320UL,
  92315648UL,    8561664UL,    8561920UL, 3645802496UL, 3260253952UL, 2924972288UL,
2505935616UL, 1851887104UL, 1097043968UL,  241472512UL,    6985728UL,    7445760UL,
3476000256UL, 3174140416UL, 2889058560UL, 2536999424UL, 1983679232UL, 1296010496UL,
 591564544UL,    5017344UL,    5870336UL, 3356659968UL, 3121580544UL, 2886502400UL,
2567997440UL, 2098694400UL, 1495107840UL,  807504640UL,  120294656UL,    4099072UL,
3204484352UL, 3003155968UL, 2835383552UL, 2583725568UL, 2214626560UL, 1744864512UL,
1124305152UL,  352749568UL,    2263040UL, 3120597760UL, 2952824064UL, 2801828608UL,
2617279488UL, 2332066816UL, 1979745024UL, 1526760192UL,  922780672UL,      33536UL,
3788396032UL, 3335674112UL, 2765315584UL, 2111136768UL, 1339450624UL,  365656576UL,
  63082752UL,   12295936UL,   11970560UL, 3719650560UL, 3249824512UL, 2813814528UL,
2310630656UL, 1589276416UL,  548961024UL,   11832576UL,   11310592UL,   11247872UL,
3701170944UL, 3248318464UL, 2828954368UL, 2342678528UL, 1604678144UL,  631601920UL,
  10717440UL,   10391808UL,   10196992UL, 3581634560UL, 3212798976UL, 2877517312UL,
2441441536UL, 1720349696UL,  831092992UL,   76251904UL,    9145344UL,    9015808UL,
3646383360UL, 3244059648UL, 2925489664UL, 2539942400UL, 1919448320UL, 1114077696UL,
 258375680UL,    7112960UL,    7442176UL, 3543625472UL, 3208146688UL, 2922934272UL,
2554163712UL, 2000712704UL, 1313044224UL,  575043840UL,    5209600UL,    5932288UL,
3373955328UL, 3105321984UL, 2870375168UL, 2534961664UL, 2065462272UL, 1478521856UL,
 807696128UL,  103643648UL,    4161024UL, 3221257728UL, 2986374656UL, 2818601984UL,
2550166528UL, 2164290560UL, 1711306240UL, 1090811648UL,  336033024UL,    2258688UL,
3087039744UL, 2936043520UL, 2768270592UL, 2566944000UL, 2264954112UL, 1879077888UL,
1459647232UL,  889221632UL,      29184UL, 3788323584UL, 3419421696UL, 2916368128UL,
2295678464UL, 1607944448UL,  920145664UL,  214853632UL,   12813056UL,   12293120UL,
3753263360UL, 3266528512UL, 2880784640UL, 2394378240UL, 1740198400UL, 1086018816UL,
 179922944UL,   11895040UL,   11439616UL, 3651028480UL, 3214821888UL, 2829012480UL,
2426556928UL, 1705399552UL,  984111104UL,  111634432UL,   10845184UL,   10520576UL,
3514846208UL, 3179433984UL, 2860864000UL, 2441565440UL, 1837848576UL, 1032804864UL,
 126903808UL,    9467648UL,    9404672UL, 3445641472UL, 3126940416UL, 2858767616UL,
2489931520UL, 1919638016UL, 1148214016UL,  225534208UL,    7761664UL,    7961344UL,
3577695744UL, 3208663808UL, 2940294144UL, 2554615552UL, 2051561984UL, 1431066624UL,
 575365120UL,    5335296UL,    6059264UL, 3525466112UL, 3189790464UL, 2921224192UL,
2535414272UL, 2065849088UL, 1478908672UL,  791240448UL,  103900160UL,    4287744UL,
3355862016UL, 3053477632UL, 2768264448UL, 2466274560UL, 2097175808UL, 1627610624UL,
1057316864UL,  302604288UL,    2319616UL, 3103812352UL, 2902484736UL, 2717934592UL,
2499830528UL, 2231395584UL, 1811964160UL, 1375756288UL,  855662592UL,      24320UL,
3771475200UL, 3486721024UL, 3034129920UL, 2413700864UL, 1608592384UL,  971255296UL,
 484522240UL,   81025280UL,   12940544UL, 3753388544UL, 3300207104UL, 2947951872UL,
2545496320UL, 1840920320UL, 1253980416UL,  767377152UL,  112875776UL,   11891200UL,
3667996416UL, 3248500736UL, 2862624768UL, 2527278080UL, 1806055424UL, 1101543680UL,
 480854016UL,   10901504UL,   10907648UL, 3531944960UL, 3179623680UL, 2860987904UL,
2475309312UL, 1905146624UL, 1150303488UL,  429080832UL,    9656320UL,    9727232UL,
3462806272UL, 3127130368UL, 2858957312UL, 2490186752UL, 1936604416UL, 1265778176UL,
 477577472UL,    8082688UL,    8283904UL, 3443932672UL, 3091611136UL, 2840018176UL,
2471116544UL, 2001616384UL, 1381056256UL,  609632256UL,    5983488UL,    6577920UL,
3643357184UL, 3207085056UL, 2905095424UL, 2536062464UL, 2083274496UL, 1529823488UL,
 993213184UL,   87509248UL,    4479232UL, 3607905024UL, 3171369216UL, 2852471296UL,
2533704448UL, 2131051776UL, 1627800832UL, 1007174912UL,  286213888UL,    2510080UL,
3238023424UL, 2952810496UL, 2717929472UL, 2466271232UL, 2181058816UL, 1761627648UL,
1291864832UL,  805325312UL,      18688UL, 3787985920UL, 3604286720UL, 3202353920UL,
2649098752UL, 1693452800UL,  904859904UL,  284233984UL,  116139008UL,   14502144UL,
3837334272UL, 3317042944UL, 3015249920UL, 2679968512UL, 1992300544UL, 1371676672UL,
 935600640UL,  616638976UL,   12140288UL, 3718584320UL, 3248690432UL, 2913210880UL,
2594640896UL, 2007635712UL, 1252793856UL,  699277056UL,  296560640UL,   11159552UL,
3565755904UL, 3196591360UL, 2878020352UL, 2508987136UL, 2022710016UL, 1267867392UL,
 580198144UL,   93792768UL,    9849344UL, 3513459456UL, 3127452416UL, 2859147264UL,
2456756224UL, 1953570816UL, 1349853440UL,  595075072UL,    8334848UL,    8538624UL,
3494717696UL, 3108710400UL, 2823562496UL, 2454660096UL, 1985094656UL, 1414865664UL,
 693772800UL,   73608960UL,    6965248UL, 3543149568UL, 3073321728UL, 2788108288UL,
2419074816UL, 1999841024UL, 1496720640UL,  859448576UL,   88091648UL,    4931328UL,
3826590976UL, 3222479872UL, 2886739456UL, 2534287104UL, 2131699712UL, 1628514560UL,
1041508608UL,  589112320UL,    2766336UL, 3590336000UL, 3087020032UL, 2768253696UL,
2499818752UL, 2214606592UL, 1761621760UL, 1241527296UL,  738210048UL,      12544UL,
3737911296UL, 3654615040UL, 3353018368UL, 2816147456UL, 2162098176UL, 1357381632UL,
 787152896UL,  485818368UL,   16711680UL, 3803643904UL, 3367370752UL, 3099197440UL,
2847866880UL, 2361720832UL, 1573584896UL, 1070333952UL,  785252352UL,   13107200UL,
3718709248UL, 3282370560UL, 2963603456UL, 2712141824UL, 2309750784UL, 1555038208UL,
 984678400UL,  682885120UL,   11599872UL, 3549233152UL, 3213688832UL, 2911764480UL,
2576416768UL, 2207449088UL, 1570045952UL,  865599488UL,  446365696UL,   10223616UL,
3328835584UL, 3178037248UL, 2876243968UL, 2507341824UL, 2071330816UL, 1551368192UL,
 813367296UL,  209780736UL,    8912896UL, 3192193024UL, 3041525760UL, 2823815168UL,
2438135808UL, 1985413120UL, 1482293248UL,  861798400UL,  140771328UL,    7405568UL,
3122659328UL, 2888105984UL, 2653618176UL, 2368798720UL, 1983250432UL, 1463418880UL,
 876412928UL,  172228608UL,    5570560UL, 3322216448UL, 2953379840UL, 2651586560UL,
2349858816UL, 1964376064UL, 1494876160UL,  975044608UL,  321191936UL,    3473408UL,
4278190080UL, 3288334336UL, 2902458368UL, 2583691264UL, 2231369728UL, 1811939328UL,
1291845632UL,  704643072UL,          0UL
};
*/

APDK_END_NAMESPACE

#endif //APDK_DJ8x5
